# Who are we?

We are a research group `Pattern Recognition and Artificial Intelligence Group` affiliated with the University of Alicante. 

To learn more about our work, please visit our [website](https://praig.ua.es/){:target="_blank"}.
